@@ -32,18 +32,15 @@ class NotebookExecutor():
                              self.zeppelin_url, self.notebook_id))
 
             if r.status_code == 500:
-                wait_time = 2**attempt
-                print('Notebook is still busy executing. Checking again in {0} seconds...'
-                      .format(wait_time))
-                time.sleep(wait_time)
-                attempt += 1
+                print('Notebook is still busy executing. Checking again in 60 seconds...')
+                time.sleep(60)
                 continue
 
             data = r.json()['body']
             if all(paragraph['status'] in ['FINISHED', 'ERROR'] for paragraph in data):
                 break
 
-            time.sleep(2)
+            time.sleep(5)
 
     def get_executed_notebook(self):
         """Return the executed notebook."""
